#'
#' @import utils

utils::globalVariables(c("age",
                         "Age",
                         "Ex",
                         "Exp",
                         "expectancy",
                         "ci.upper",
                         "Model",
                         "ci.lower",
                         "X1",
                         "X2",
                         "X3",
                         "X4",
                         "Year",
                         "ages",
                         "autocor",
                         "iteration",
                         "lim.inf",
                         "lim.sup",
                         "log.qx",
                         "qx.lower",
                         "qx.upper",
                         "qx",
                         "qx.fitted",
                         "samples",
                         "year",
                         "yint"
                         ))
